/* DO NOT MODIFY THIS FILE!  It was generated by `recode/tables.py'.  */

/* Conversion of files between different charsets and surfaces.
   Copyright © 1999 Free Software Foundation, Inc.
   Contributed by François Pinard <pinard@iro.umontreal.ca>, 1993, 1997.

   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public License
   as published by the Free Software Foundation; either version 3 of the
   License, or (at your option) any later version.

   This library is distributed in the hope that it will be
   useful, but WITHOUT ANY WARRANTY; without even the implied warranty
   of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the Recode Library; see the file `COPYING.LIB'.
   If not, see <https://www.gnu.org/licenses/>.
   Suite 330, Boston, MA 02111-1307, USA.  */

#include "config.h"
#include "common.h"
#include "decsteps.h"

/* ISO_646.basic
   ref
   ISO_646.basic:1983
*/

static struct strip_data data_0 =
  {
    ucs2_data_pool,
    {
         0,    0,    0,    0,    8,   16,   24,   32,   40,   48,   56,   64,
        72,   80,   88,   96,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* INVARIANT
   iso-ir-170
*/

static struct strip_data data_1 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,    8,   16,   24,   32,   40,   48,   56,   64,
        72,   80,   88,  136,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO_646.irv
   iso-ir-2
   ISO_646.irv:1983
   irv
*/

static struct strip_data data_2 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  176,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* BS_4730
   iso-ir-4
   ISO646-GB
   gb
   uk
*/

static struct strip_data data_3 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  176,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ANSI_X3.4-1968
   iso-ir-6
   ANSI_X3.4-1986
   ISO_646.irv:1991
   ASCII
   ISO646-US
   US-ASCII
   us
   IBM367
   CP367
   367
*/

static struct strip_data data_4 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NATS-SEFI
   iso-ir-8-1
*/

static struct strip_data data_5 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  208,   48,   56,  216,
       224,   80,   88,  232,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NATS-SEFI-ADD
   iso-ir-8-2
*/

static struct strip_data data_6 =
  {
    ucs2_data_pool,
    {
         0,    0,    0,    0,    0,    0,    0,    0,  240,    0,  248,  256,
       264,    0,  272,  280,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NATS-DANO
   iso-ir-9-1
*/

static struct strip_data data_7 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  288,   16,   24,   32,  208,   48,   56,  296,
       224,   80,   88,  304,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NATS-DANO-ADD
   iso-ir-9-2
*/

static struct strip_data data_8 =
  {
    ucs2_data_pool,
    {
         0,    0,    0,    0,    0,    0,    0,    0,  240,    0,  248,  312,
       264,    0,  272,  320,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* SEN_850200_B
   iso-ir-10
   FI
   ISO646-FI
   ISO646-SE
   se
   SS636127
*/

static struct strip_data data_9 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56,  328,
       168,   80,   88,  336,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* SEN_850200_C
   iso-ir-11
   ISO646-SE2
   se2
*/

static struct strip_data data_10 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  344,   48,   56,  352,
       360,   80,   88,  368,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6220-1969-jp
   JIS_C6220-1969
   iso-ir-13
   katakana
   x0201-7
*/

static struct strip_data data_11 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  376,  384,  392,  400,  408,  416,  424,  432,
         0,    0,    0,  440,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6220-1969-ro
   iso-ir-14
   jp
   ISO646-JP
*/

static struct strip_data data_12 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  448,
       168,   80,   88,  176,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* IT
   iso-ir-15
   ISO646-IT
*/

static struct strip_data data_13 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  456,   48,   56,  464,
       472,   80,   88,  480,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* PT
   iso-ir-16
   ISO646-PT
*/

static struct strip_data data_14 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  456,   48,   56,  488,
       168,   80,   88,  496,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ES
   iso-ir-17
   ISO646-ES
*/

static struct strip_data data_15 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  456,   48,   56,  504,
       168,   80,   88,  512,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* greek7-old
   iso-ir-18
*/

static struct strip_data data_16 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  520,  528,  536,  544,
       552,  560,  568,  576,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* latin-greek
   iso-ir-19
*/

static struct strip_data data_17 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  152,   48,   56,  160,
       552,  560,  568,  584,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* DIN_66003
   iso-ir-21
   de
   ISO646-DE
*/

static struct strip_data data_18 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  456,   48,   56,  592,
       168,   80,   88,  600,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NF_Z_62-010_(1973)
   iso-ir-25
   ISO646-FR1
*/

static struct strip_data data_19 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  608,   48,   56,  616,
       168,   80,   88,  624,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* Latin-greek-1
   iso-ir-27
*/

static struct strip_data data_20 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  632,   16,   24,  640,  648,   48,   56,  656,
       168,   80,   88,  176,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO_5427
   iso-ir-37
*/

static struct strip_data data_21 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  664,  672,  680,  688,
       696,  704,  712,  720,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* BS_viewdata
   iso-ir-47
*/

static struct strip_data data_22 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  152,   48,   56,  728,
       168,   80,   88,  736,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* INIS
   iso-ir-49
*/

static struct strip_data data_23 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  744,   16,   24,  752,   40,   48,   56,  760,
        72,   80,   88,  768,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* INIS-8
   iso-ir-50
*/

static struct strip_data data_24 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  776,    0,    0,  784,    0,    0,    0,  792,
       800,  808,  816,  824,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* INIS-cyrillic
   iso-ir-51
*/

static struct strip_data data_25 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  776,  832,  840,  848,  664,  672,  680,  688,
       696,  704,  712,  720,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO_5427-ext
   iso-ir-54
   ISO_5427:1981
*/

static struct strip_data data_26 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  776,    0,    0,    0,  856,  864,  872,  880,
       888,  896,  904,  440,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO_5428
   iso-ir-55
   ISO_5428:1980
*/

static struct strip_data data_27 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  912,    0,  920,  928,  936,  944,  952,  960,
       968,  976,  984,  992,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* GB_1988-80
   iso-ir-57
   cn
   ISO646-CN
*/

static struct strip_data data_28 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128, 1000,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  176,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NS_4551-1
   iso-ir-60
   ISO646-NO
   no
*/

static struct strip_data data_29 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56, 1008,
       168,   80,   88, 1016,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NS_4551-2
   ISO646-NO2
   iso-ir-61
   no2
*/

static struct strip_data data_30 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128, 1024,   16,   24,   32,  152,   48,   56, 1008,
       168,   80,   88, 1032,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NF_Z_62-010
   iso-ir-69
   ISO646-FR
   fr
*/

static struct strip_data data_31 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  184,   16,   24,   32,  608,   48,   56,  616,
      1040,   80,   88,  624,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* PT2
   iso-ir-84
   ISO646-PT2
*/

static struct strip_data data_32 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32, 1048,   48,   56,  488,
       168,   80,   88, 1056,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ES2
   iso-ir-85
   ISO646-ES2
*/

static struct strip_data data_33 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32, 1064,   48,   56, 1072,
       168,   80,   88, 1080,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* MSZ_7795.3
   iso-ir-86
   ISO646-HU
   hu
*/

static struct strip_data data_34 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32, 1088,   48,   56, 1096,
      1104,   80,   88, 1112,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* greek7
   iso-ir-88
*/

static struct strip_data data_35 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32, 1120, 1128, 1136, 1144,
      1152, 1160, 1168, 1176,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ASMO_449
   ISO_9036
   arabic7
   iso-ir-89
*/

static struct strip_data data_36 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144, 1184,   24, 1192, 1200, 1208, 1216, 1224,
      1232, 1240, 1248, 1256,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6229-1984-a
   iso-ir-91
   jp-ocr-a
*/

static struct strip_data data_37 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128, 1264,   16,   24, 1272,   40,   48,   56, 1280,
         0,    0,    0, 1288,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6229-1984-b
   iso-ir-92
   ISO646-JP-OCR-B
   jp-ocr-b
*/

static struct strip_data data_38 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56, 1296,
        72,   80,   88, 1304,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6229-1984-b-add
   iso-ir-93
   jp-ocr-b-add
*/

static struct strip_data data_39 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128, 1312,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,  440,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6229-1984-hand
   iso-ir-94
   jp-ocr-hand
*/

static struct strip_data data_40 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56, 1296,
         0,    0,    0, 1320,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6229-1984-hand-add
   iso-ir-95
   jp-ocr-hand-add
*/

static struct strip_data data_41 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128, 1328,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,  440,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_C6229-1984-kana
   iso-ir-96
*/

static struct strip_data data_42 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128, 1336,    0,  392,  400,  408,  416,  424,  432,
         0,    0,    0,  440,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO_2033-1983
   iso-ir-98
   e13b
*/

static struct strip_data data_43 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  776,    0,   24, 1344,    0,    0,    0,    0,
         0,    0,    0,  440,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO-8859-1
   iso-ir-100
   ISO_8859-1:1987
   ISO_8859-1
   ISO8859-1
   latin1
   l1
   IBM819
   CP819
   819
*/

static struct strip_data data_44 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1384, 1392, 1400, 1408,
      1416, 1424, 1432, 1440, 1448, 1456, 1464, 1472
    }
  };

/* ISO-8859-2
   iso-ir-101
   ISO_8859-2:1987
   ISO_8859-2
   ISO8859-2
   latin2
   l2
   IBM912
   CP912
   912
*/

static struct strip_data data_45 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1480, 1488, 1496, 1504,
      1512, 1520, 1528, 1536, 1544, 1552, 1560, 1568
    }
  };

/* T.61-7bit
   iso-ir-102
*/

static struct strip_data data_46 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56, 1576,
        72,   80,   88,  768,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO-8859-3
   iso-ir-109
   ISO_8859-3:1988
   ISO_8859-3
   ISO8859-3
   latin3
   l3
*/

static struct strip_data data_47 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1584, 1592, 1600, 1608,
      1616, 1424, 1624, 1632, 1640, 1456, 1648, 1656
    }
  };

/* ISO-8859-4
   iso-ir-110
   ISO_8859-4:1988
   ISO_8859-4
   ISO8859-4
   latin4
   l4
*/

static struct strip_data data_48 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1664, 1672, 1680, 1688,
      1696, 1704, 1712, 1720, 1728, 1736, 1744, 1752
    }
  };

/* ECMA-cyrillic
   iso-ir-111
   ECMA-113:1986
   ECMA-113
*/

static struct strip_data data_49 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1760, 1768, 1776, 1784,
       664,  672,  680,  688,  696,  704,  712, 1792
    }
  };

/* CSA_Z243.4-1985-1
   iso-ir-121
   ISO646-CA
   csa7-1
   ca
*/

static struct strip_data data_50 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  608,   48,   56, 1800,
      1808,   80,   88, 1816,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* CSA_Z243.4-1985-2
   iso-ir-122
   ISO646-CA2
   csa7-2
*/

static struct strip_data data_51 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  608,   48,   56, 1824,
      1808,   80,   88, 1816,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* CSA_Z243.4-1985-gr
   iso-ir-123
*/

static struct strip_data data_52 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1832, 1840,  800, 1848,
      1856, 1864, 1872, 1880, 1888, 1896, 1904, 1912
    }
  };

/* ISO-8859-7
   iso-ir-126
   ISO_8859-7:1987
   ISO_8859-7
   ISO8859-7
   ELOT_928
   ECMA-118
   greek
   greek8
*/

static struct strip_data data_53 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1920, 1928, 1936, 1944,
      1952, 1960, 1968, 1976, 1984, 1992, 2000, 2008
    }
  };

/* ISO-8859-6
   iso-ir-127
   ISO_8859-6:1987
   ISO_8859-6
   ISO8859-6
   ECMA-114
   ASMO-708
   arabic
*/

static struct strip_data data_54 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2016, 2024,    0, 2032,
      2040, 1208, 1216, 2048, 1232, 1240, 1248,    0
    }
  };

/* ISO-8859-8
   iso-ir-138
   ISO_8859-8:1988
   ISO_8859-8
   ISO8859-8
   hebrew
*/

static struct strip_data data_55 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2056, 2064, 1400, 2072,
         0,    0,    0, 2080, 2088, 2096, 2104, 2112
    }
  };

/* CSN_369103
   iso-ir-139
   KOI-8_L2
   koi8l2
*/

static struct strip_data data_56 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2120, 1488, 1496, 1504,
      1512, 1520, 1528, 1536, 1544, 1552, 1560, 1568
    }
  };

/* JUS_I.B1.002
   iso-ir-141
   ISO646-YU
   js
   yu
*/

static struct strip_data data_57 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32, 2128,   48,   56, 2136,
      2144,   80,   88, 2152,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* IEC_P27-1
   iso-ir-143
*/

static struct strip_data data_58 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2160, 2168, 2176, 2184,
      2192, 2200, 2208, 2216, 2224, 2232, 2240, 2248
    }
  };

/* ISO-8859-5
   iso-ir-144
   ISO_8859-5:1988
   ISO_8859-5
   ISO8859-5
   cyrillic
*/

static struct strip_data data_59 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2256, 2264, 2272, 2280,
      2288, 2296, 2304, 2312, 2320, 2328, 2336, 2344
    }
  };

/* JUS_I.B1.003-serb
   iso-ir-146
   serbian
*/

static struct strip_data data_60 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32, 2352, 2360, 2368, 2376,
      2384, 2392, 2400, 2408,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JUS_I.B1.003-mac
   macedonian
   iso-ir-147
*/

static struct strip_data data_61 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32, 2352, 2360, 2368, 2416,
      2384, 2392, 2400, 2424,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO-8859-9
   iso-ir-148
   ISO_8859-9:1989
   ISO_8859-9
   ISO8859-9
   latin5
   l5
*/

static struct strip_data data_62 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 1384, 1392, 1400, 1408,
      1416, 1424, 2432, 2440, 1448, 2448, 2456, 2464
    }
  };

/* greek-ccitt
   iso-ir-150
*/

static struct strip_data data_63 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32, 1120, 1960, 1968, 2472,
      2480, 1992, 2000, 2488,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* NC_NC00-10
   cuba
   NC_NC00-10:81
   iso-ir-151
   ISO646-CU
*/

static struct strip_data data_64 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56, 2496,
       168,   80,   88, 2504,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* ISO_6937-2-25
   iso-ir-152
*/

static struct strip_data data_65 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2512, 2520,    0, 2528,
         0,    0, 2536, 2544, 2552, 2560, 2568, 2576
    }
  };

/* GOST_19768-87
   ST_SEV_358-88
   iso-ir-153
*/

static struct strip_data data_66 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2584, 2592, 2272, 2280,
      2288, 2296, 2304, 2312, 2320, 2328, 2600,    0
    }
  };

/* ISO_8859-supp
   iso-ir-154
   latin1-2-5
*/

static struct strip_data data_67 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2608, 2616, 2624, 2632,
      2640, 2648, 2656, 2664, 2672, 2680, 2688, 2696
    }
  };

/* ISO_10367-box
   iso-ir-155
*/

static struct strip_data data_68 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376,    0,    0,    0,    0,
      2704, 2712, 2720, 2728,    0,    0,    0,    0
    }
  };

/* ISO-8859-10
   iso-ir-157
   ISO_8859-10:1993
   ISO_8859-10
   ISO8859-10
   L6
   latin6
*/

static struct strip_data data_69 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2736, 2744, 2752, 2760,
      1696, 2768, 2776, 2784, 1728, 2792, 2800, 2808
    }
  };

/* ISO-8859-13
   iso-ir-179a
   ISO_8859-13:1998
   ISO_8859-13
   ISO8859-13
   latin7
   iso-baltic
   l7
*/

static struct strip_data data_70 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2816, 1392, 2824, 1408,
      2832, 2840, 2848, 2856, 2864, 2872, 2880, 2888
    }
  };

/* ISO-8859-14
   iso-ir-199
   ISO_8859-14:1998
   ISO_8859-14
   ISO8859-14
   latin8
   iso-celtic
   l8
*/

static struct strip_data data_71 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2896, 2904, 2912, 2920,
      1416, 1424, 2928, 2936, 1448, 1456, 2944, 2952
    }
  };

/* ISO-8859-15
   iso-ir-203
   ISO_8859-15:1998
   ISO_8859-15
   ISO8859-15
   latin9
   l9
*/

static struct strip_data data_72 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2960, 2968, 2976, 2984,
      1416, 1424, 1432, 1440, 1448, 1456, 1464, 1472
    }
  };

/* sami
   latin-lap
   lap
   iso-ir-158
*/

static struct strip_data data_73 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 2992,    0, 3000,    0,
      3008, 3016,    0,    0, 3024, 3032,    0,    0
    }
  };

/* baltic
   iso-ir-179
*/

static struct strip_data data_74 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 3040, 3048, 1400, 3056,
      3064, 3072, 3080, 3088, 3096, 3104, 3112, 3120
    }
  };

/* DS_2089
   DS2089
   ISO646-DK
   dk
*/

static struct strip_data data_75 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56, 1008,
       168,   80,   88, 3128,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* JIS_X0201
   X0201
*/

static struct strip_data data_76 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  448,
       168,   80,   88,  176, 1352, 1360, 1368, 1376, 3136,  384,  392,  400,
       408,  416,  424,  432,    0,    0,    0,    0
    }
  };

/* KSC5636
   ISO646-KR
*/

static struct strip_data data_77 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56, 3144,
       168,   80,   88,  200,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* DEC-MCS
   dec
*/

static struct strip_data data_78 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 3152, 3160, 3168, 3176,
      1416, 1424, 3184, 3192, 1448, 1456, 3200, 3208
    }
  };

/* hp-roman8
   roman8
   r8
*/

static struct strip_data data_79 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 1352, 1360, 1368, 1376, 3216, 3224, 3232, 3240,
      3248, 3256, 3264, 3272, 3280, 3288, 3296, 3304
    }
  };

/* NeXTSTEP
   next
*/

static struct strip_data data_80 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 3312, 1424, 3320, 3328, 3336, 3344, 3352, 3360,
      3368, 3376, 3384, 3392, 3400, 3408, 3416, 3424
    }
  };

/* macintosh
   mac
*/

static struct strip_data data_81 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 3432, 3440, 3448, 3456, 3464, 3472, 3480, 3488,
      3496, 3504, 3512, 3520, 3528, 3536, 3544, 3552
    }
  };

/* mac-is
*/

static struct strip_data data_82 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 3432, 3440, 3448, 3456, 3464, 3472, 3480, 3488,
      3496, 3560, 3568, 3576, 3528, 3536, 3544, 3552
    }
  };

/* IBM037
   CP037
   037
   ebcdic-cp-us
   ebcdic-cp-ca
   ebcdic-cp-wt
   ebcdic-cp-nl
*/

static struct strip_data data_83 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 3656, 3664, 3672,
      3680, 3688, 3696, 3704, 3712, 3720, 3728, 3736, 3744, 3752, 3760, 3768,
      3776, 3784, 3792, 3800, 3808, 3816,   24, 3824
    }
  };

/* IBM038
   EBCDIC-INT
   CP038
   038
*/

static struct strip_data data_84 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 3832, 3840, 3848,
      3856, 3864,    0, 3872,   72, 3880, 3888, 3896, 3904, 3912,    0,    0,
      3776, 3920, 3792, 3928, 3936, 3944,   24, 3952
    }
  };

/* IBM256
   EBCDIC-INT1
   CP256
   256
*/

static struct strip_data data_85 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 3960, 3664, 3968,
      3680, 3688, 3696, 3704, 3712, 3720, 3728, 3736, 3744, 3752, 3976, 3984,
      3776, 3784, 3792, 3800, 3992, 3816,   24, 3824
    }
  };

/* IBM273
   CP273
   273
*/

static struct strip_data data_86 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4000, 4008, 3664, 4016,
      4024, 4032, 3696, 4040, 3712, 3720, 3728, 3736, 4048, 3752, 4056, 4064,
      4072, 4080, 4088, 4096, 4104, 4112,   24, 4120
    }
  };

/* IBM274
   EBCDIC-BE
   CP274
   274
*/

static struct strip_data data_87 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 3832, 3840, 3848,
      3856, 4128,    0, 4136,   72, 3880, 3888, 3896, 4144, 3912,    0,    0,
      4152, 3920, 4160, 3928, 4168, 3944,   24, 3952
    }
  };

/* IBM275
   EBCDIC-BR
   CP275
   275
*/

static struct strip_data data_88 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 4176, 3840, 4184,
      3856, 4192,    0, 4200,   72, 3880, 3888, 3896, 3904, 3912,    0,    0,
      4208, 3920, 4216, 3928, 3936, 3944,   24, 3952
    }
  };

/* IBM277
   EBCDIC-CP-DK
   EBCDIC-CP-NO
*/

static struct strip_data data_89 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4224, 4232, 3664, 4240,
      4248, 4256, 4264, 4272, 4280, 3720, 3728, 4288, 4296, 3752, 4304, 4064,
      4312, 3784, 4320, 4328, 3808, 3816,   24, 3824
    }
  };

/* IBM278
   CP278
   278
   ebcdic-cp-fi
   ebcdic-cp-se
*/

static struct strip_data data_90 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4336, 4344, 4352, 4240,
      4360, 4032, 3696, 4368, 3712, 3720, 3728, 4376, 4296, 3752, 4384, 4064,
      4072, 4080, 4320, 4328, 3808, 4392,   24, 3824
    }
  };

/* IBM280
   CP280
   280
   ebcdic-cp-it
*/

static struct strip_data data_91 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4400, 4408, 4416, 4424,
      3680, 4432, 3696, 4440, 3712, 3720, 4448, 3736, 4456, 3752, 4464, 4064,
       608, 4472, 4160, 4480, 4488, 3816,   24, 3824
    }
  };

/* IBM281
   EBCDIC-JP-E
   CP281
   281
*/

static struct strip_data data_92 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 4496, 3840, 4504,
      3856, 3864,    0, 3872,   72, 3880, 3888, 3896, 4512, 3912,    0,    0,
      3776, 3920, 3792, 3928, 4520, 3944,   24, 3952
    }
  };

/* IBM284
   CP284
   284
   ebcdic-cp-es
*/

static struct strip_data data_93 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 4528, 3664, 4536,
      3680, 4544, 3696, 4552, 3712, 3720, 3728, 3736, 4560, 3752, 4304, 4568,
      3776, 3784, 3792, 3800, 3808, 3816,   24, 3824
    }
  };

/* IBM285
   CP285
   285
   ebcdic-cp-gb
*/

static struct strip_data data_94 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 4576, 3664, 4584,
      3680, 3688, 3696, 3704, 3712, 3720, 3728, 3736, 4592, 3752, 4600, 4608,
      3776, 3784, 3792, 3800, 3808, 3816,   24, 3824
    }
  };

/* IBM290
   CP290
   290
   EBCDIC-JP-kana
*/

static struct strip_data data_95 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  376, 4616, 4624, 4632,
      3856, 3864,    0, 3872, 4640, 4648, 4656, 4664, 4672, 4680,    0, 4688,
        40, 3920, 4696, 3928, 4520, 3944,   24, 3952
    }
  };

/* IBM297
   CP297
   297
   ebcdic-cp-fr
*/

static struct strip_data data_96 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4704, 4408, 4712, 4720,
      3680, 4728, 3696, 4736, 3712, 3720, 4448, 3736, 4744, 3752, 4752, 4760,
      4152, 3784, 4160, 4768, 4488, 3816,   24, 3824
    }
  };

/* IBM420
   CP420
   420
   ebcdic-cp-ar1
*/

static struct strip_data data_97 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4776, 4784, 4792, 4800,
      4808, 4816, 4824, 4832, 4840, 4848, 4856, 4864, 4872, 4880, 4888, 4896,
      4904, 4912, 4920, 4928, 4936, 4944,   24, 4952
    }
  };

/* IBM423
   CP423
   423
   ebcdic-cp-gr
*/

static struct strip_data data_98 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4960, 4968, 4976, 4984,
      4992, 5000, 5008, 5016, 5024, 5032, 5040, 5048, 5056, 5064, 5072, 5080,
      5088, 5096, 5104, 5112, 5120, 5128,   24, 5136
    }
  };

/* IBM424
   CP424
   424
   ebcdic-cp-he
*/

static struct strip_data data_99 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 5144, 5152, 5160, 5168,
      5176, 5184, 5192, 5200,   72, 5208, 3728, 5216, 3744, 5224, 3760, 5232,
      3776, 5240, 3792, 5248, 3808, 5256,   24, 5264
    }
  };

/* IBM437
   CP437
   437
*/

static struct strip_data data_100 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5272, 5280, 5288, 5296, 5304, 5312, 5320, 5328,
      5336, 5344, 5352, 5360, 5368, 5376, 5384, 5392
    }
  };

/* IBM500
   CP500
   500
   500V1
   ebcdic-cp-be
   ebcdic-cp-ch
*/

static struct strip_data data_101 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 3960, 3664, 3968,
      3680, 3688, 3696, 3704, 3712, 3720, 3728, 3736, 3744, 3752, 4304, 5400,
      3776, 3784, 3792, 3800, 3808, 3816,   24, 3824
    }
  };

/* IBM850
   CP850
   850
*/

static struct strip_data data_102 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5272, 5280, 5288, 5408, 5304, 5416, 5424, 5432,
      5440, 5448, 5456, 5464, 5472, 5480, 5488, 5496
    }
  };

/* IBM851
   CP851
   851
*/

static struct strip_data data_103 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5504, 5512, 5520, 5528, 5536, 5544, 5552, 5560,
      5568, 5576, 5584, 5592, 5600, 5608, 5616, 5624
    }
  };

/* IBM852
   CP852
   852
   pcl2
   pclatin2
*/

static struct strip_data data_104 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5632, 5640, 5648, 5656, 5664, 5672, 5680, 5688,
      5696, 5448, 5704, 5712, 5720, 5728, 5736, 5744
    }
  };

/* IBM855
   CP855
   855
*/

static struct strip_data data_105 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5752, 5760, 5768, 5776, 5784, 5792, 5800, 5808,
      5816, 5448, 5824, 5832, 5840, 5848, 5856, 5864
    }
  };

/* IBM857
   CP857
   857
*/

static struct strip_data data_106 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5272, 5872, 5288, 5880, 5888, 5416, 5424, 5432,
      5440, 5448, 5896, 5464, 5904, 5912, 5920, 5928
    }
  };

/* IBM860
   CP860
   860
*/

static struct strip_data data_107 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5936, 5944, 5952, 5960, 5304, 5968, 5320, 5328,
      5336, 5344, 5352, 5360, 5368, 5376, 5384, 5392
    }
  };

/* IBM861
   CP861
   861
   cp-is
*/

static struct strip_data data_108 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5272, 5976, 5984, 5992, 6000, 6008, 5320, 5328,
      5336, 5344, 5352, 5360, 5368, 5376, 5384, 5392
    }
  };

/* IBM862
   CP862
   862
*/

static struct strip_data data_109 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 2088, 2096, 2104, 6016, 5304, 6008, 5320, 5328,
      5336, 5344, 5352, 5360, 5368, 5376, 5384, 5392
    }
  };

/* IBM863
   CP863
   863
*/

static struct strip_data data_110 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 6024, 6032, 6040, 6048, 6056, 6064, 5320, 5328,
      5336, 5344, 5352, 5360, 5368, 6072, 5384, 6080
    }
  };

/* IBM864
   CP864
   864
*/

static struct strip_data data_111 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 6088, 6096, 6104, 6112, 6120, 6128, 6136, 6144,
      6152, 6160, 6168, 6176, 6184, 6192, 6200, 6208
    }
  };

/* IBM865
   CP865
   865
*/

static struct strip_data data_112 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5272, 5280, 5288, 6216, 5304, 5312, 5320, 5328,
      5336, 5344, 5352, 5360, 5368, 6072, 5384, 6080
    }
  };

/* IBM868
   CP868
   868
   cp-ar
*/

static struct strip_data data_113 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 6136, 6224, 6232, 6240, 6248, 6256, 6264, 6272,
      6280, 6288, 6296, 6304, 6312, 6320, 6328, 6336
    }
  };

/* IBM869
   CP869
   869
   cp-gr
*/

static struct strip_data data_114 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 6344, 6352, 6360, 6368, 5536, 5544, 6376, 6384,
      5568, 5576, 5584, 5592, 5600, 5608, 6392, 5624
    }
  };

/* IBM870
   CP870
   870
   ebcdic-cp-roece
   ebcdic-cp-yu
*/

static struct strip_data data_115 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 6400, 6408, 6416, 6424,
      6432, 6440, 6448, 6456, 6464, 6472, 3728, 6480, 6488, 6496, 6504, 6512,
      3776, 6520, 3792, 6528, 3808, 6536,   24, 6544
    }
  };

/* IBM871
   CP871
   871
   ebcdic-cp-is
*/

static struct strip_data data_116 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 6552, 3664, 6560,
      3680, 3688, 3696, 6568, 3712, 6576, 3728, 6584, 6592, 6600, 4304, 6608,
      6616, 6624, 6632, 3800, 6640, 6648,   24, 3824
    }
  };

/* IBM875
   CP875
   875
   EBCDIC-Greek
*/

static struct strip_data data_117 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 4960, 4968, 4976, 4984,
      4992, 6656, 6664, 6672, 6680, 5032, 3728, 5048, 6688, 6696, 6704, 6712,
      3776, 6720, 3792, 6728, 3936, 6736,   24, 6744
    }
  };

/* IBM880
   CP880
   880
   EBCDIC-Cyrillic
*/

static struct strip_data data_118 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 6752, 6760, 6768, 6776,
      6784, 6792, 6800, 6808, 6816, 6824, 6832, 6840, 6848, 6856,  688,  696,
        40, 6864, 4696, 6872, 6880, 6888,   24, 6896
    }
  };

/* IBM891
   CP891
   891
*/

static struct strip_data data_119 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* IBM903
   CP903
   903
*/

static struct strip_data data_120 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* IBM904
   CP904
   904
*/

static struct strip_data data_121 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 6904,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0, 6912
    }
  };

/* IBM905
   CP905
   905
   ebcdic-cp-tr
*/

static struct strip_data data_122 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 6920, 6928, 3664, 6936,
      6944, 6952, 6960, 6968, 6464, 6976, 3728, 6984, 6592, 6992, 7000, 7008,
      7016, 7024, 7032, 7040, 7048, 7056,   24, 7064
    }
  };

/* IBM918
   CP918
   918
   ebcdic-cp-ar2
*/

static struct strip_data data_123 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 7072, 7080, 7088, 7096,
      7104, 7112, 6136, 7120, 7128, 7136, 3888, 7144, 7152, 7160, 7168, 7176,
      3776, 7184, 3792, 7192, 3936, 7200,   24, 7208
    }
  };

/* IBM1004
   CP1004
   1004
   os2latin1
*/

static struct strip_data data_124 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7216, 7224, 7232, 7240, 1384, 1392, 1400, 1408,
      1416, 1424, 1432, 1440, 1448, 1456, 1464, 1472
    }
  };

/* IBM1026
   CP1026
   1026
*/

static struct strip_data data_125 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 6928, 3664, 6936,
      3680, 6952, 3696, 6968, 3712, 7248, 3728, 7256, 6592, 7264, 4304, 7272,
      7016, 6624, 7032, 7280, 7048, 7288,   24, 7064
    }
  };

/* IBM1047
   CP1047
   1047
*/

static struct strip_data data_126 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 3648, 3656, 3664, 7296,
      3680, 3688, 3696, 3704, 3712, 3720, 3728, 3736, 3744, 7304, 7312, 7320,
      3776, 3784, 3792, 3800, 3808, 3816,   24, 3824
    }
  };

/* CP1250
   ms-ee
   1250
   windows-1250
*/

static struct strip_data data_127 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7328, 7336, 7232, 7344, 7352, 7360, 7368, 7376,
      1512, 1520, 1528, 1536, 1544, 1552, 1560, 1568
    }
  };

/* CP1251
   ms-cyrl
   1251
   windows-1251
*/

static struct strip_data data_128 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7384, 7392, 7400, 7408, 7416, 7424, 7432, 7440,
      2272, 2280, 2288, 2296, 2304, 2312, 2320, 2328
    }
  };

/* CP1252
   ms-ansi
   1252
   windows-1252
*/

static struct strip_data data_129 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7448, 7456, 7232, 7464, 1384, 1392, 1400, 1408,
      1416, 1424, 1432, 1440, 1448, 1456, 1464, 1472
    }
  };

/* CP1253
   ms-greek
   1253
   windows-1253
*/

static struct strip_data data_130 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7448, 7472, 7232, 7480, 7488, 7496, 7504, 1944,
      1952, 1960, 1968, 1976, 1984, 1992, 2000, 2008
    }
  };

/* CP1254
   ms-turk
   1254
   windows-1254
*/

static struct strip_data data_131 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7448, 7224, 7232, 7240, 1384, 1392, 1400, 1408,
      1416, 1424, 2432, 2440, 1448, 2448, 2456, 2464
    }
  };

/* CP1255
   ms-hebr
   1255
   windows-1255
*/

static struct strip_data data_132 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7448, 7472, 7232, 7480, 2056, 2064, 1400, 2072,
         0,    0,    0, 2080, 2088, 2096, 2104, 7512
    }
  };

/* CP1256
   ms-arab
   1256
   windows-1256
*/

static struct strip_data data_133 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7520, 7528, 7536, 7544, 7552, 7560, 7568, 7576,
      7584, 7592, 7600, 7608, 7616, 7624, 7632, 7640
    }
  };

/* CP1257
   WinBaltRim
   1257
   windows-1257
*/

static struct strip_data data_134 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 7328, 7472, 7232, 7480, 7648, 7656, 3168, 7664,
      2832, 2840, 2848, 2856, 2864, 2872, 2880, 7672
    }
  };

/* EBCDIC-AT-DE
*/

static struct strip_data data_135 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7680, 3840, 7688,
      3856, 7696,    0, 7704,   72, 3880, 3888, 3896, 7712, 3912,    0,    0,
      4072, 3920, 4088, 3928, 7720, 3944,   24, 3952
    }
  };

/* EBCDIC-AT-DE-A
*/

static struct strip_data data_136 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7728, 3840, 7736,
      3856, 7744,    0, 7752,   72, 3880, 3888, 3896, 7760, 3912,    0,    0,
        40, 3920, 4696, 3928, 7768, 3944,   24, 3952
    }
  };

/* EBCDIC-CA-FR
*/

static struct strip_data data_137 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640, 7776, 7784, 7792, 7800,
      7808, 7816, 7824, 3872,   72, 3880, 3888, 3896, 4144, 3912,    0,    0,
      4152, 7832, 4160, 7840, 7848, 7856,   24, 7864
    }
  };

/* EBCDIC-DK-NO
*/

static struct strip_data data_138 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7872, 3840, 7880,
      3856, 7888,    0, 7896,   72, 3880, 3888, 3896, 7904, 3912,    0,    0,
      4312, 3920, 4320, 3928, 3936, 3944,   24, 3952
    }
  };

/* EBCDIC-DK-NO-A
*/

static struct strip_data data_139 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7912, 3840, 7920,
      3856, 3864,    0, 7928,   72, 3880, 3888, 3896, 7760, 3912,    0,    0,
        40, 3920, 4696, 3928, 7768, 3944,   24, 3952
    }
  };

/* EBCDIC-FI-SE
*/

static struct strip_data data_140 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7936, 3840, 7880,
      3856, 7696,    0, 7944,   72, 3880, 3888, 3896, 7904, 3912,    0,    0,
      4072, 3920, 4320, 3928, 7952, 3944,   24, 3952
    }
  };

/* EBCDIC-FI-SE-A
*/

static struct strip_data data_141 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7728, 3840, 7920,
      3856, 3864,    0, 7752,   72, 3880, 3888, 3896, 7760, 3912,    0,    0,
        40, 3920, 4696, 3928, 7768, 3944,   24, 3952
    }
  };

/* EBCDIC-FR
*/

static struct strip_data data_142 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7960, 3840, 7968,
      3856, 4128,    0, 7976,   72, 3880, 3888, 3896, 4144, 3912,    0,    0,
      4152, 3920, 4160, 3928, 4168, 3944,   24, 3952
    }
  };

/* EBCDIC-IT
*/

static struct strip_data data_143 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 7960, 3840, 7984,
      3856, 7992,    0, 8000,   72, 3880, 3888, 3896, 8008, 3912,    0,    0,
       608, 3920, 4160, 3928, 4168, 3944,   24, 3952
    }
  };

/* EBCDIC-PT
*/

static struct strip_data data_144 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 3832, 3840, 3848,
      3856, 8016,    0, 8024,   72, 3880, 3888, 3896, 8032, 3912,    0,    0,
      8040, 3920, 5104, 3928, 8048, 3944,   24, 3952
    }
  };

/* EBCDIC-ES
*/

static struct strip_data data_145 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 8056, 3840, 8064,
      3856, 8072,    0, 8080,   72, 3880, 3888, 3896, 4144, 3912,    0,    0,
      3776, 3920, 3792, 3928, 3936, 3944,   24, 3952
    }
  };

/* EBCDIC-ES-A
*/

static struct strip_data data_146 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 8056, 3840, 8064,
      3856, 3864,    0, 8088,   72, 3880, 3888, 3896, 7760, 3912,    0,    0,
        40, 3920, 4696, 3928, 7768, 3944,   24, 3952
    }
  };

/* EBCDIC-ES-S
*/

static struct strip_data data_147 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 8056, 3840, 8096,
      3856, 8072,    0, 8080,   72, 3880, 3888, 3896, 4144, 3912,    0,    0,
      3776, 3920, 3792, 3928, 3936, 3944,   24, 3952
    }
  };

/* EBCDIC-UK
*/

static struct strip_data data_148 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 8104, 3840, 8112,
      3856, 3864,    0, 3872,   72, 3880, 3888, 3896, 4512, 3912,    0,    0,
      3776, 3920, 3792, 3928, 3936, 3944,   24, 3952
    }
  };

/* EBCDIC-US
*/

static struct strip_data data_149 =
  {
    ucs2_data_pool,
    {
      3584, 3592, 3600, 3608, 3616, 3624, 3632, 3640,  776, 8056, 3840, 8096,
      3856, 3864,    0, 3872,   72, 3880, 3888, 3896, 3904, 3912,    0,    0,
      3776, 3920, 3792, 3928, 3936, 3944,   24, 3952
    }
  };

/* EBCDIC-IS-FRISS
   friss
*/

static struct strip_data data_150 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,    0,    0,    0,    0, 8120, 8128, 8136, 8144,
      3856, 8152, 8160, 8168,   72, 8176, 3888, 3896, 8184, 8192,    0, 8200,
      8208, 8216, 6632, 8224, 8232, 8240,   24, 8248
    }
  };

/* KOI-7
*/

static struct strip_data data_151 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  144,   16,   24,   32,  152,   48,   56,  160,
       696,  704,  712,  720,    0,    0,    0,    0,    0,    0,    0,    0,
         0,    0,    0,    0,    0,    0,    0,    0
    }
  };

/* KOI-8
   GOST_19768-74
*/

static struct strip_data data_152 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200,    0,    0,    0,    0,    0,    0,    0,    0,
       664,  672,  680,  688,  696,  704,  712, 8256
    }
  };

/* KOI8-R
*/

static struct strip_data data_153 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 8264, 8272, 8280, 8288, 8296, 8304, 8312, 8320,
       664,  672,  680,  688,  696,  704,  712, 1792
    }
  };

/* KOI8-RU
*/

static struct strip_data data_154 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 8264, 8272, 8328, 8336, 8344, 8352, 8360, 8368,
       664,  672,  680,  688,  696,  704,  712, 1792
    }
  };

/* KOI8-U
*/

static struct strip_data data_155 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 8264, 8272, 8376, 8288, 8344, 8384, 8360, 8392,
       664,  672,  680,  688,  696,  704,    0,    0
    }
  };

/* CWI
   CWI-2
   cp-hu
*/

static struct strip_data data_156 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 5272, 8400, 8408, 8416, 8424, 5312, 5320, 5328,
      5336, 5344, 5352, 5360, 8432, 6072, 5384, 6080
    }
  };

/* macintosh_ce
   macce
*/

static struct strip_data data_157 =
  {
    ucs2_data_pool,
    {
       104,  112,  120,  128,  192,   16,   24,   32,  152,   48,   56,  160,
       168,   80,   88,  200, 8440, 8448, 8456, 8464, 8472, 8480, 8488, 8496,
      8504, 8512, 8520, 8528, 8536, 8544, 8552, 8560
    }
  };

_GL_ATTRIBUTE_CONST bool
module_strips (_GL_UNUSED struct recode_outer *outer)
{
  RECODE_ALIAS alias;

  if (!recode_declare_strip_data (outer, &data_0, "ISO_646.basic"))
    return false;
  if (!recode_declare_strip_data (outer, &data_1, "INVARIANT"))
    return false;
  if (!recode_declare_strip_data (outer, &data_2, "ISO_646.irv"))
    return false;
  if (!recode_declare_strip_data (outer, &data_3, "BS_4730"))
    return false;
  if (!recode_declare_strip_data (outer, &data_4, "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_strip_data (outer, &data_5, "NATS-SEFI"))
    return false;
  if (!recode_declare_strip_data (outer, &data_6, "NATS-SEFI-ADD"))
    return false;
  if (!recode_declare_strip_data (outer, &data_7, "NATS-DANO"))
    return false;
  if (!recode_declare_strip_data (outer, &data_8, "NATS-DANO-ADD"))
    return false;
  if (!recode_declare_strip_data (outer, &data_9, "SEN_850200_B"))
    return false;
  if (!recode_declare_strip_data (outer, &data_10, "SEN_850200_C"))
    return false;
  if (!recode_declare_strip_data (outer, &data_11, "JIS_C6220-1969-jp"))
    return false;
  if (!recode_declare_strip_data (outer, &data_12, "JIS_C6220-1969-ro"))
    return false;
  if (!recode_declare_strip_data (outer, &data_13, "IT"))
    return false;
  if (!recode_declare_strip_data (outer, &data_14, "PT"))
    return false;
  if (!recode_declare_strip_data (outer, &data_15, "ES"))
    return false;
  if (!recode_declare_strip_data (outer, &data_16, "greek7-old"))
    return false;
  if (!recode_declare_strip_data (outer, &data_17, "latin-greek"))
    return false;
  if (!recode_declare_strip_data (outer, &data_18, "DIN_66003"))
    return false;
  if (!recode_declare_strip_data (outer, &data_19, "NF_Z_62-010_(1973)"))
    return false;
  if (!recode_declare_strip_data (outer, &data_20, "Latin-greek-1"))
    return false;
  if (!recode_declare_strip_data (outer, &data_21, "ISO_5427"))
    return false;
  if (!recode_declare_strip_data (outer, &data_22, "BS_viewdata"))
    return false;
  if (!recode_declare_strip_data (outer, &data_23, "INIS"))
    return false;
  if (!recode_declare_strip_data (outer, &data_24, "INIS-8"))
    return false;
  if (!recode_declare_strip_data (outer, &data_25, "INIS-cyrillic"))
    return false;
  if (!recode_declare_strip_data (outer, &data_26, "ISO_5427-ext"))
    return false;
  if (!recode_declare_strip_data (outer, &data_27, "ISO_5428"))
    return false;
  if (!recode_declare_strip_data (outer, &data_28, "GB_1988-80"))
    return false;
  if (!recode_declare_strip_data (outer, &data_29, "NS_4551-1"))
    return false;
  if (!recode_declare_strip_data (outer, &data_30, "NS_4551-2"))
    return false;
  if (!recode_declare_strip_data (outer, &data_31, "NF_Z_62-010"))
    return false;
  if (!recode_declare_strip_data (outer, &data_32, "PT2"))
    return false;
  if (!recode_declare_strip_data (outer, &data_33, "ES2"))
    return false;
  if (!recode_declare_strip_data (outer, &data_34, "MSZ_7795.3"))
    return false;
  if (!recode_declare_strip_data (outer, &data_35, "greek7"))
    return false;
  if (!recode_declare_strip_data (outer, &data_36, "ASMO_449"))
    return false;
  if (!recode_declare_strip_data (outer, &data_37, "JIS_C6229-1984-a"))
    return false;
  if (!recode_declare_strip_data (outer, &data_38, "JIS_C6229-1984-b"))
    return false;
  if (!recode_declare_strip_data (outer, &data_39, "JIS_C6229-1984-b-add"))
    return false;
  if (!recode_declare_strip_data (outer, &data_40, "JIS_C6229-1984-hand"))
    return false;
  if (!recode_declare_strip_data (outer, &data_41, "JIS_C6229-1984-hand-add"))
    return false;
  if (!recode_declare_strip_data (outer, &data_42, "JIS_C6229-1984-kana"))
    return false;
  if (!recode_declare_strip_data (outer, &data_43, "ISO_2033-1983"))
    return false;
  if (!recode_declare_strip_data (outer, &data_44, "ISO-8859-1"))
    return false;
  if (!recode_declare_strip_data (outer, &data_45, "ISO-8859-2"))
    return false;
  if (!recode_declare_strip_data (outer, &data_46, "T.61-7bit"))
    return false;
  if (!recode_declare_strip_data (outer, &data_47, "ISO-8859-3"))
    return false;
  if (!recode_declare_strip_data (outer, &data_48, "ISO-8859-4"))
    return false;
  if (!recode_declare_strip_data (outer, &data_49, "ECMA-cyrillic"))
    return false;
  if (!recode_declare_strip_data (outer, &data_50, "CSA_Z243.4-1985-1"))
    return false;
  if (!recode_declare_strip_data (outer, &data_51, "CSA_Z243.4-1985-2"))
    return false;
  if (!recode_declare_strip_data (outer, &data_52, "CSA_Z243.4-1985-gr"))
    return false;
  if (!recode_declare_strip_data (outer, &data_53, "ISO-8859-7"))
    return false;
  if (!recode_declare_strip_data (outer, &data_54, "ISO-8859-6"))
    return false;
  if (!recode_declare_strip_data (outer, &data_55, "ISO-8859-8"))
    return false;
  if (!recode_declare_strip_data (outer, &data_56, "CSN_369103"))
    return false;
  if (!recode_declare_strip_data (outer, &data_57, "JUS_I.B1.002"))
    return false;
  if (!recode_declare_strip_data (outer, &data_58, "IEC_P27-1"))
    return false;
  if (!recode_declare_strip_data (outer, &data_59, "ISO-8859-5"))
    return false;
  if (!recode_declare_strip_data (outer, &data_60, "JUS_I.B1.003-serb"))
    return false;
  if (!recode_declare_strip_data (outer, &data_61, "JUS_I.B1.003-mac"))
    return false;
  if (!recode_declare_strip_data (outer, &data_62, "ISO-8859-9"))
    return false;
  if (!recode_declare_strip_data (outer, &data_63, "greek-ccitt"))
    return false;
  if (!recode_declare_strip_data (outer, &data_64, "NC_NC00-10"))
    return false;
  if (!recode_declare_strip_data (outer, &data_65, "ISO_6937-2-25"))
    return false;
  if (!recode_declare_strip_data (outer, &data_66, "GOST_19768-87"))
    return false;
  if (!recode_declare_strip_data (outer, &data_67, "ISO_8859-supp"))
    return false;
  if (!recode_declare_strip_data (outer, &data_68, "ISO_10367-box"))
    return false;
  if (!recode_declare_strip_data (outer, &data_69, "ISO-8859-10"))
    return false;
  if (!recode_declare_strip_data (outer, &data_70, "ISO-8859-13"))
    return false;
  if (!recode_declare_strip_data (outer, &data_71, "ISO-8859-14"))
    return false;
  if (!recode_declare_strip_data (outer, &data_72, "ISO-8859-15"))
    return false;
  if (!recode_declare_strip_data (outer, &data_73, "sami"))
    return false;
  if (!recode_declare_strip_data (outer, &data_74, "baltic"))
    return false;
  if (!recode_declare_strip_data (outer, &data_75, "DS_2089"))
    return false;
  if (!recode_declare_strip_data (outer, &data_76, "JIS_X0201"))
    return false;
  if (!recode_declare_strip_data (outer, &data_77, "KSC5636"))
    return false;
  if (!recode_declare_strip_data (outer, &data_78, "DEC-MCS"))
    return false;
  if (!recode_declare_strip_data (outer, &data_79, "hp-roman8"))
    return false;
  if (!recode_declare_strip_data (outer, &data_80, "NeXTSTEP"))
    return false;
  if (!recode_declare_strip_data (outer, &data_81, "macintosh"))
    return false;
  if (!recode_declare_strip_data (outer, &data_82, "mac-is"))
    return false;
  if (!recode_declare_strip_data (outer, &data_83, "IBM037"))
    return false;
  if (!recode_declare_strip_data (outer, &data_84, "IBM038"))
    return false;
  if (!recode_declare_strip_data (outer, &data_85, "IBM256"))
    return false;
  if (!recode_declare_strip_data (outer, &data_86, "IBM273"))
    return false;
  if (!recode_declare_strip_data (outer, &data_87, "IBM274"))
    return false;
  if (!recode_declare_strip_data (outer, &data_88, "IBM275"))
    return false;
  if (!recode_declare_strip_data (outer, &data_89, "IBM277"))
    return false;
  if (!recode_declare_strip_data (outer, &data_90, "IBM278"))
    return false;
  if (!recode_declare_strip_data (outer, &data_91, "IBM280"))
    return false;
  if (!recode_declare_strip_data (outer, &data_92, "IBM281"))
    return false;
  if (!recode_declare_strip_data (outer, &data_93, "IBM284"))
    return false;
  if (!recode_declare_strip_data (outer, &data_94, "IBM285"))
    return false;
  if (!recode_declare_strip_data (outer, &data_95, "IBM290"))
    return false;
  if (!recode_declare_strip_data (outer, &data_96, "IBM297"))
    return false;
  if (!recode_declare_strip_data (outer, &data_97, "IBM420"))
    return false;
  if (!recode_declare_strip_data (outer, &data_98, "IBM423"))
    return false;
  if (!recode_declare_strip_data (outer, &data_99, "IBM424"))
    return false;
  if (!recode_declare_strip_data (outer, &data_100, "IBM437"))
    return false;
  if (!recode_declare_strip_data (outer, &data_101, "IBM500"))
    return false;
  if (!recode_declare_strip_data (outer, &data_102, "IBM850"))
    return false;
  if (!recode_declare_strip_data (outer, &data_103, "IBM851"))
    return false;
  if (!recode_declare_strip_data (outer, &data_104, "IBM852"))
    return false;
  if (!recode_declare_strip_data (outer, &data_105, "IBM855"))
    return false;
  if (!recode_declare_strip_data (outer, &data_106, "IBM857"))
    return false;
  if (!recode_declare_strip_data (outer, &data_107, "IBM860"))
    return false;
  if (!recode_declare_strip_data (outer, &data_108, "IBM861"))
    return false;
  if (!recode_declare_strip_data (outer, &data_109, "IBM862"))
    return false;
  if (!recode_declare_strip_data (outer, &data_110, "IBM863"))
    return false;
  if (!recode_declare_strip_data (outer, &data_111, "IBM864"))
    return false;
  if (!recode_declare_strip_data (outer, &data_112, "IBM865"))
    return false;
  if (!recode_declare_strip_data (outer, &data_113, "IBM868"))
    return false;
  if (!recode_declare_strip_data (outer, &data_114, "IBM869"))
    return false;
  if (!recode_declare_strip_data (outer, &data_115, "IBM870"))
    return false;
  if (!recode_declare_strip_data (outer, &data_116, "IBM871"))
    return false;
  if (!recode_declare_strip_data (outer, &data_117, "IBM875"))
    return false;
  if (!recode_declare_strip_data (outer, &data_118, "IBM880"))
    return false;
  if (!recode_declare_strip_data (outer, &data_119, "IBM891"))
    return false;
  if (!recode_declare_strip_data (outer, &data_120, "IBM903"))
    return false;
  if (!recode_declare_strip_data (outer, &data_121, "IBM904"))
    return false;
  if (!recode_declare_strip_data (outer, &data_122, "IBM905"))
    return false;
  if (!recode_declare_strip_data (outer, &data_123, "IBM918"))
    return false;
  if (!recode_declare_strip_data (outer, &data_124, "IBM1004"))
    return false;
  if (!recode_declare_strip_data (outer, &data_125, "IBM1026"))
    return false;
  if (!recode_declare_strip_data (outer, &data_126, "IBM1047"))
    return false;
  if (!recode_declare_strip_data (outer, &data_127, "CP1250"))
    return false;
  if (!recode_declare_strip_data (outer, &data_128, "CP1251"))
    return false;
  if (!recode_declare_strip_data (outer, &data_129, "CP1252"))
    return false;
  if (!recode_declare_strip_data (outer, &data_130, "CP1253"))
    return false;
  if (!recode_declare_strip_data (outer, &data_131, "CP1254"))
    return false;
  if (!recode_declare_strip_data (outer, &data_132, "CP1255"))
    return false;
  if (!recode_declare_strip_data (outer, &data_133, "CP1256"))
    return false;
  if (!recode_declare_strip_data (outer, &data_134, "CP1257"))
    return false;
  if (!recode_declare_strip_data (outer, &data_135, "EBCDIC-AT-DE"))
    return false;
  if (!recode_declare_strip_data (outer, &data_136, "EBCDIC-AT-DE-A"))
    return false;
  if (!recode_declare_strip_data (outer, &data_137, "EBCDIC-CA-FR"))
    return false;
  if (!recode_declare_strip_data (outer, &data_138, "EBCDIC-DK-NO"))
    return false;
  if (!recode_declare_strip_data (outer, &data_139, "EBCDIC-DK-NO-A"))
    return false;
  if (!recode_declare_strip_data (outer, &data_140, "EBCDIC-FI-SE"))
    return false;
  if (!recode_declare_strip_data (outer, &data_141, "EBCDIC-FI-SE-A"))
    return false;
  if (!recode_declare_strip_data (outer, &data_142, "EBCDIC-FR"))
    return false;
  if (!recode_declare_strip_data (outer, &data_143, "EBCDIC-IT"))
    return false;
  if (!recode_declare_strip_data (outer, &data_144, "EBCDIC-PT"))
    return false;
  if (!recode_declare_strip_data (outer, &data_145, "EBCDIC-ES"))
    return false;
  if (!recode_declare_strip_data (outer, &data_146, "EBCDIC-ES-A"))
    return false;
  if (!recode_declare_strip_data (outer, &data_147, "EBCDIC-ES-S"))
    return false;
  if (!recode_declare_strip_data (outer, &data_148, "EBCDIC-UK"))
    return false;
  if (!recode_declare_strip_data (outer, &data_149, "EBCDIC-US"))
    return false;
  if (!recode_declare_strip_data (outer, &data_150, "EBCDIC-IS-FRISS"))
    return false;
  if (!recode_declare_strip_data (outer, &data_151, "KOI-7"))
    return false;
  if (!recode_declare_strip_data (outer, &data_152, "KOI-8"))
    return false;
  if (!recode_declare_strip_data (outer, &data_153, "KOI8-R"))
    return false;
  if (!recode_declare_strip_data (outer, &data_154, "KOI8-RU"))
    return false;
  if (!recode_declare_strip_data (outer, &data_155, "KOI8-U"))
    return false;
  if (!recode_declare_strip_data (outer, &data_156, "CWI"))
    return false;
  if (!recode_declare_strip_data (outer, &data_157, "macintosh_ce"))
    return false;

  if (!recode_declare_alias (outer, "ref", "ISO_646.basic"))
    return false;
  if (!recode_declare_alias (outer, "ISO_646.basic:1983", "ISO_646.basic"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-170", "INVARIANT"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-2", "ISO_646.irv"))
    return false;
  if (!recode_declare_alias (outer, "ISO_646.irv:1983", "ISO_646.irv"))
    return false;
  if (!recode_declare_alias (outer, "irv", "ISO_646.irv"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-4", "BS_4730"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-GB", "BS_4730"))
    return false;
  if (!recode_declare_alias (outer, "gb", "BS_4730"))
    return false;
  if (!recode_declare_alias (outer, "uk", "BS_4730"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-6", "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_alias (outer, "ANSI_X3.4-1986", "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_alias (outer, "ISO_646.irv:1991", "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_alias (outer, "ASCII", "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-US", "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_alias (outer, "US-ASCII", "ANSI_X3.4-1968"))
    return false;
  if (!recode_declare_alias (outer, "us", "ANSI_X3.4-1968"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM367", "ANSI_X3.4-1968"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP367", "ANSI_X3.4-1968"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "367", "ANSI_X3.4-1968"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-8-1", "NATS-SEFI"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-8-2", "NATS-SEFI-ADD"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-9-1", "NATS-DANO"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-9-2", "NATS-DANO-ADD"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-10", "SEN_850200_B"))
    return false;
  if (!recode_declare_alias (outer, "FI", "SEN_850200_B"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-FI", "SEN_850200_B"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-SE", "SEN_850200_B"))
    return false;
  if (!recode_declare_alias (outer, "se", "SEN_850200_B"))
    return false;
  if (!recode_declare_alias (outer, "SS636127", "SEN_850200_B"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-11", "SEN_850200_C"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-SE2", "SEN_850200_C"))
    return false;
  if (!recode_declare_alias (outer, "se2", "SEN_850200_C"))
    return false;
  if (!recode_declare_alias (outer, "JIS_C6220-1969", "JIS_C6220-1969-jp"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-13", "JIS_C6220-1969-jp"))
    return false;
  if (!recode_declare_alias (outer, "katakana", "JIS_C6220-1969-jp"))
    return false;
  if (!recode_declare_alias (outer, "x0201-7", "JIS_C6220-1969-jp"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-14", "JIS_C6220-1969-ro"))
    return false;
  if (!recode_declare_alias (outer, "jp", "JIS_C6220-1969-ro"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-JP", "JIS_C6220-1969-ro"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-15", "IT"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-IT", "IT"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-16", "PT"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-PT", "PT"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-17", "ES"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-ES", "ES"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-18", "greek7-old"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-19", "latin-greek"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-21", "DIN_66003"))
    return false;
  if (!recode_declare_alias (outer, "de", "DIN_66003"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-DE", "DIN_66003"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-25", "NF_Z_62-010_(1973)"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-FR1", "NF_Z_62-010_(1973)"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-27", "Latin-greek-1"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-37", "ISO_5427"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-47", "BS_viewdata"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-49", "INIS"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-50", "INIS-8"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-51", "INIS-cyrillic"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-54", "ISO_5427-ext"))
    return false;
  if (!recode_declare_alias (outer, "ISO_5427:1981", "ISO_5427-ext"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-55", "ISO_5428"))
    return false;
  if (!recode_declare_alias (outer, "ISO_5428:1980", "ISO_5428"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-57", "GB_1988-80"))
    return false;
  if (!recode_declare_alias (outer, "cn", "GB_1988-80"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-CN", "GB_1988-80"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-60", "NS_4551-1"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-NO", "NS_4551-1"))
    return false;
  if (!recode_declare_alias (outer, "no", "NS_4551-1"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-NO2", "NS_4551-2"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-61", "NS_4551-2"))
    return false;
  if (!recode_declare_alias (outer, "no2", "NS_4551-2"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-69", "NF_Z_62-010"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-FR", "NF_Z_62-010"))
    return false;
  if (!recode_declare_alias (outer, "fr", "NF_Z_62-010"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-84", "PT2"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-PT2", "PT2"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-85", "ES2"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-ES2", "ES2"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-86", "MSZ_7795.3"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-HU", "MSZ_7795.3"))
    return false;
  if (!recode_declare_alias (outer, "hu", "MSZ_7795.3"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-88", "greek7"))
    return false;
  if (!recode_declare_alias (outer, "ISO_9036", "ASMO_449"))
    return false;
  if (!recode_declare_alias (outer, "arabic7", "ASMO_449"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-89", "ASMO_449"))
    return false;
  if (!recode_declare_alias (outer, "jp-ocr-a", "JIS_C6229-1984-a"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-JP-OCR-B", "JIS_C6229-1984-b"))
    return false;
  if (!recode_declare_alias (outer, "jp-ocr-b", "JIS_C6229-1984-b"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-93", "JIS_C6229-1984-b-add"))
    return false;
  if (!recode_declare_alias (outer, "jp-ocr-b-add", "JIS_C6229-1984-b-add"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-94", "JIS_C6229-1984-hand"))
    return false;
  if (!recode_declare_alias (outer, "jp-ocr-hand", "JIS_C6229-1984-hand"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-95", "JIS_C6229-1984-hand-add"))
    return false;
  if (!recode_declare_alias (outer, "jp-ocr-hand-add", "JIS_C6229-1984-hand-add"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-96", "JIS_C6229-1984-kana"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-98", "ISO_2033-1983"))
    return false;
  if (!recode_declare_alias (outer, "e13b", "ISO_2033-1983"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-100", "ISO-8859-1"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-1:1987", "ISO-8859-1"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-1", "ISO-8859-1"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-1", "ISO-8859-1"))
    return false;
  if (!recode_declare_alias (outer, "latin1", "ISO-8859-1"))
    return false;
  if (!recode_declare_alias (outer, "l1", "ISO-8859-1"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM819", "ISO-8859-1"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP819", "ISO-8859-1"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "819", "ISO-8859-1"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-101", "ISO-8859-2"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-2:1987", "ISO-8859-2"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-2", "ISO-8859-2"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-2", "ISO-8859-2"))
    return false;
  if (!recode_declare_alias (outer, "latin2", "ISO-8859-2"))
    return false;
  if (!recode_declare_alias (outer, "l2", "ISO-8859-2"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM912", "ISO-8859-2"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP912", "ISO-8859-2"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "912", "ISO-8859-2"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-102", "T.61-7bit"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-109", "ISO-8859-3"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-3:1988", "ISO-8859-3"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-3", "ISO-8859-3"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-3", "ISO-8859-3"))
    return false;
  if (!recode_declare_alias (outer, "latin3", "ISO-8859-3"))
    return false;
  if (!recode_declare_alias (outer, "l3", "ISO-8859-3"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-110", "ISO-8859-4"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-4:1988", "ISO-8859-4"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-4", "ISO-8859-4"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-4", "ISO-8859-4"))
    return false;
  if (!recode_declare_alias (outer, "latin4", "ISO-8859-4"))
    return false;
  if (!recode_declare_alias (outer, "l4", "ISO-8859-4"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-111", "ECMA-cyrillic"))
    return false;
  if (!recode_declare_alias (outer, "ECMA-113:1986", "ECMA-cyrillic"))
    return false;
  if (!recode_declare_alias (outer, "ECMA-113", "ECMA-cyrillic"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-121", "CSA_Z243.4-1985-1"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-CA", "CSA_Z243.4-1985-1"))
    return false;
  if (!recode_declare_alias (outer, "csa7-1", "CSA_Z243.4-1985-1"))
    return false;
  if (!recode_declare_alias (outer, "ca", "CSA_Z243.4-1985-1"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-122", "CSA_Z243.4-1985-2"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-CA2", "CSA_Z243.4-1985-2"))
    return false;
  if (!recode_declare_alias (outer, "csa7-2", "CSA_Z243.4-1985-2"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-123", "CSA_Z243.4-1985-gr"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-126", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-7:1987", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-7", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-7", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "ELOT_928", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "ECMA-118", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "greek", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "greek8", "ISO-8859-7"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-127", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-6:1987", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-6", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-6", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "ECMA-114", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "ASMO-708", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "arabic", "ISO-8859-6"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-138", "ISO-8859-8"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-8:1988", "ISO-8859-8"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-8", "ISO-8859-8"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-8", "ISO-8859-8"))
    return false;
  if (!recode_declare_alias (outer, "hebrew", "ISO-8859-8"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-139", "CSN_369103"))
    return false;
  if (!recode_declare_alias (outer, "KOI-8_L2", "CSN_369103"))
    return false;
  if (!recode_declare_alias (outer, "koi8l2", "CSN_369103"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-141", "JUS_I.B1.002"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-YU", "JUS_I.B1.002"))
    return false;
  if (!recode_declare_alias (outer, "js", "JUS_I.B1.002"))
    return false;
  if (!recode_declare_alias (outer, "yu", "JUS_I.B1.002"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-143", "IEC_P27-1"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-144", "ISO-8859-5"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-5:1988", "ISO-8859-5"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-5", "ISO-8859-5"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-5", "ISO-8859-5"))
    return false;
  if (!recode_declare_alias (outer, "cyrillic", "ISO-8859-5"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-146", "JUS_I.B1.003-serb"))
    return false;
  if (!recode_declare_alias (outer, "serbian", "JUS_I.B1.003-serb"))
    return false;
  if (!recode_declare_alias (outer, "macedonian", "JUS_I.B1.003-mac"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-147", "JUS_I.B1.003-mac"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-148", "ISO-8859-9"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-9:1989", "ISO-8859-9"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-9", "ISO-8859-9"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-9", "ISO-8859-9"))
    return false;
  if (!recode_declare_alias (outer, "latin5", "ISO-8859-9"))
    return false;
  if (!recode_declare_alias (outer, "l5", "ISO-8859-9"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-150", "greek-ccitt"))
    return false;
  if (!recode_declare_alias (outer, "cuba", "NC_NC00-10"))
    return false;
  if (!recode_declare_alias (outer, "NC_NC00-10:81", "NC_NC00-10"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-151", "NC_NC00-10"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-CU", "NC_NC00-10"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-152", "ISO_6937-2-25"))
    return false;
  if (!recode_declare_alias (outer, "ST_SEV_358-88", "GOST_19768-87"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-153", "GOST_19768-87"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-154", "ISO_8859-supp"))
    return false;
  if (!recode_declare_alias (outer, "latin1-2-5", "ISO_8859-supp"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-155", "ISO_10367-box"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-157", "ISO-8859-10"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-10:1993", "ISO-8859-10"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-10", "ISO-8859-10"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-10", "ISO-8859-10"))
    return false;
  if (!recode_declare_alias (outer, "L6", "ISO-8859-10"))
    return false;
  if (!recode_declare_alias (outer, "latin6", "ISO-8859-10"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-179a", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-13:1998", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-13", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-13", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "latin7", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "iso-baltic", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "l7", "ISO-8859-13"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-199", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-14:1998", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-14", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-14", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "latin8", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "iso-celtic", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "l8", "ISO-8859-14"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-203", "ISO-8859-15"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-15:1998", "ISO-8859-15"))
    return false;
  if (!recode_declare_alias (outer, "ISO_8859-15", "ISO-8859-15"))
    return false;
  if (!recode_declare_alias (outer, "ISO8859-15", "ISO-8859-15"))
    return false;
  if (!recode_declare_alias (outer, "latin9", "ISO-8859-15"))
    return false;
  if (!recode_declare_alias (outer, "l9", "ISO-8859-15"))
    return false;
  if (!recode_declare_alias (outer, "latin-lap", "sami"))
    return false;
  if (!recode_declare_alias (outer, "lap", "sami"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-158", "sami"))
    return false;
  if (!recode_declare_alias (outer, "iso-ir-179", "baltic"))
    return false;
  if (!recode_declare_alias (outer, "DS2089", "DS_2089"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-DK", "DS_2089"))
    return false;
  if (!recode_declare_alias (outer, "dk", "DS_2089"))
    return false;
  if (!recode_declare_alias (outer, "X0201", "JIS_X0201"))
    return false;
  if (!recode_declare_alias (outer, "ISO646-KR", "KSC5636"))
    return false;
  if (!recode_declare_alias (outer, "dec", "DEC-MCS"))
    return false;
  if (!recode_declare_alias (outer, "roman8", "hp-roman8"))
    return false;
  if (!recode_declare_alias (outer, "r8", "hp-roman8"))
    return false;
  if (!recode_declare_alias (outer, "next", "NeXTSTEP"))
    return false;
  if (alias = recode_declare_alias (outer, "macintosh", "macintosh"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->cr_surface))
    return false;
  if (alias = recode_declare_alias (outer, "mac", "macintosh"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->cr_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM037", "IBM037"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP037", "IBM037"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "037", "IBM037"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-us", "IBM037"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-ca", "IBM037"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-wt", "IBM037"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-nl", "IBM037"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM038", "IBM038"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-INT", "IBM038"))
    return false;
  if (alias = recode_declare_alias (outer, "CP038", "IBM038"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "038", "IBM038"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM256", "IBM256"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-INT1", "IBM256"))
    return false;
  if (alias = recode_declare_alias (outer, "CP256", "IBM256"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "256", "IBM256"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM273", "IBM273"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP273", "IBM273"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "273", "IBM273"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM274", "IBM274"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-BE", "IBM274"))
    return false;
  if (alias = recode_declare_alias (outer, "CP274", "IBM274"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "274", "IBM274"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM275", "IBM275"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-BR", "IBM275"))
    return false;
  if (alias = recode_declare_alias (outer, "CP275", "IBM275"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "275", "IBM275"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM277", "IBM277"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-CP-DK", "IBM277"))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-CP-NO", "IBM277"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM278", "IBM278"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP278", "IBM278"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "278", "IBM278"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-fi", "IBM278"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-se", "IBM278"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM280", "IBM280"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP280", "IBM280"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "280", "IBM280"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-it", "IBM280"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM281", "IBM281"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-JP-E", "IBM281"))
    return false;
  if (alias = recode_declare_alias (outer, "CP281", "IBM281"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "281", "IBM281"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM284", "IBM284"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP284", "IBM284"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "284", "IBM284"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-es", "IBM284"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM285", "IBM285"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP285", "IBM285"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "285", "IBM285"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-gb", "IBM285"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM290", "IBM290"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP290", "IBM290"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "290", "IBM290"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-JP-kana", "IBM290"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM297", "IBM297"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP297", "IBM297"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "297", "IBM297"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-fr", "IBM297"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM420", "IBM420"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP420", "IBM420"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "420", "IBM420"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-ar1", "IBM420"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM423", "IBM423"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP423", "IBM423"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "423", "IBM423"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-gr", "IBM423"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM424", "IBM424"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP424", "IBM424"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "424", "IBM424"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-he", "IBM424"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM437", "IBM437"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP437", "IBM437"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "437", "IBM437"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM500", "IBM500"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP500", "IBM500"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "500", "IBM500"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "500V1", "IBM500"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-be", "IBM500"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-ch", "IBM500"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM850", "IBM850"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP850", "IBM850"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "850", "IBM850"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM851", "IBM851"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP851", "IBM851"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "851", "IBM851"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM852", "IBM852"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP852", "IBM852"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "852", "IBM852"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "pcl2", "IBM852"))
    return false;
  if (!recode_declare_alias (outer, "pclatin2", "IBM852"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM855", "IBM855"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP855", "IBM855"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "855", "IBM855"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM857", "IBM857"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP857", "IBM857"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "857", "IBM857"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM860", "IBM860"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP860", "IBM860"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "860", "IBM860"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM861", "IBM861"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP861", "IBM861"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "861", "IBM861"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "cp-is", "IBM861"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM862", "IBM862"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP862", "IBM862"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "862", "IBM862"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM863", "IBM863"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP863", "IBM863"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "863", "IBM863"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM864", "IBM864"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP864", "IBM864"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "864", "IBM864"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM865", "IBM865"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP865", "IBM865"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "865", "IBM865"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM868", "IBM868"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP868", "IBM868"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "868", "IBM868"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "cp-ar", "IBM868"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM869", "IBM869"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP869", "IBM869"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "869", "IBM869"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "cp-gr", "IBM869"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM870", "IBM870"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP870", "IBM870"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "870", "IBM870"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-roece", "IBM870"))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-yu", "IBM870"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM871", "IBM871"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP871", "IBM871"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "871", "IBM871"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-is", "IBM871"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM875", "IBM875"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP875", "IBM875"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "875", "IBM875"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-Greek", "IBM875"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM880", "IBM880"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP880", "IBM880"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "880", "IBM880"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "EBCDIC-Cyrillic", "IBM880"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM891", "IBM891"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP891", "IBM891"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "891", "IBM891"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM903", "IBM903"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP903", "IBM903"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "903", "IBM903"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM904", "IBM904"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP904", "IBM904"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "904", "IBM904"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM905", "IBM905"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP905", "IBM905"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "905", "IBM905"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-tr", "IBM905"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM918", "IBM918"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP918", "IBM918"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "918", "IBM918"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ebcdic-cp-ar2", "IBM918"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM1004", "IBM1004"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP1004", "IBM1004"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "1004", "IBM1004"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "os2latin1", "IBM1004"))
    return false;
  if (alias = recode_declare_alias (outer, "IBM1026", "IBM1026"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP1026", "IBM1026"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "1026", "IBM1026"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "IBM1047", "IBM1047"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP1047", "IBM1047"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "1047", "IBM1047"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (alias = recode_declare_alias (outer, "CP1250", "CP1250"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-ee", "CP1250"))
    return false;
  if (alias = recode_declare_alias (outer, "1250", "CP1250"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1250", "CP1250"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1251", "CP1251"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-cyrl", "CP1251"))
    return false;
  if (alias = recode_declare_alias (outer, "1251", "CP1251"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1251", "CP1251"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1252", "CP1252"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-ansi", "CP1252"))
    return false;
  if (alias = recode_declare_alias (outer, "1252", "CP1252"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1252", "CP1252"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1253", "CP1253"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-greek", "CP1253"))
    return false;
  if (alias = recode_declare_alias (outer, "1253", "CP1253"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1253", "CP1253"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1254", "CP1254"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-turk", "CP1254"))
    return false;
  if (alias = recode_declare_alias (outer, "1254", "CP1254"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1254", "CP1254"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1255", "CP1255"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-hebr", "CP1255"))
    return false;
  if (alias = recode_declare_alias (outer, "1255", "CP1255"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1255", "CP1255"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1256", "CP1256"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "ms-arab", "CP1256"))
    return false;
  if (alias = recode_declare_alias (outer, "1256", "CP1256"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1256", "CP1256"))
    return false;
  if (alias = recode_declare_alias (outer, "CP1257", "CP1257"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "WinBaltRim", "CP1257"))
    return false;
  if (alias = recode_declare_alias (outer, "1257", "CP1257"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->crlf_surface))
    return false;
  if (!recode_declare_alias (outer, "windows-1257", "CP1257"))
    return false;
  if (!recode_declare_alias (outer, "friss", "EBCDIC-IS-FRISS"))
    return false;
  if (!recode_declare_alias (outer, "GOST_19768-74", "KOI-8"))
    return false;
  if (!recode_declare_alias (outer, "CWI-2", "CWI"))
    return false;
  if (!recode_declare_alias (outer, "cp-hu", "CWI"))
    return false;
  if (alias = recode_declare_alias (outer, "macintosh_ce", "macintosh_ce"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->cr_surface))
    return false;
  if (alias = recode_declare_alias (outer, "macce", "macintosh_ce"), !alias)
    return false;
  if (!recode_declare_implied_surface (outer, alias, outer->cr_surface))
    return false;

  return true;
}

void
delmodule_strips (_GL_UNUSED struct recode_outer *outer)
{
}
